@@ -170,7 +170,14 @@ print("Uploading image...")
 # At this stage, the SDK granted the permission to start transferring the disk, and the
 # user should choose its preferred tool for doing it - regardless of the SDK.
 # In this example, we will use Python's httplib.HTTPSConnection for transferring the data.
-destination_url = urlparse(transfer.transfer_url) if direct_upload else urlparse(transfer.proxy_url)
+if direct_upload:
+    if transfer.transfer_url is not None:
+        destination_url = urlparse(transfer.transfer_url)
+    else:
+        print("Direct upload to host not supported (requires ovirt-engine 4.2 or above).")
+        sys.exit(1)
+else:
+    destination_url = urlparse(transfer.proxy_url)
 context = ssl.create_default_context()
 
 # Note that ovirt-imageio-proxy by default checks the certificates, so if you don't have
@@ -185,19 +192,19 @@ proxy_connection = HTTPSConnection(
 
 # Send the request head. Note the following:
 #
-# - We must send the Authorzation header with the signed ticket received
-#   from the transfer service.
+# - For ovirt-engine < 4.2, we must send the 'Authorization' header with
+#   the signed ticket received from the transfer service.
+#   I.e. proxy_connection.putheader('Authorization', transfer.signed_ticket)
 #
-# - the server requires Content-Range header even when sending the
-#   entire file.
+# - For ovirt-engine < 4.2, the server requires 'Content-Range' header
+#   even when sending the entire file.
+#   I.e. proxy_connection.putheader('Content-Range',
+#            "bytes %d-%d/%d" % (0, image_size - 1, image_size))
 #
 # - the server requires also Content-Length.
 #
 
 proxy_connection.putrequest("PUT", destination_url.path)
-proxy_connection.putheader('Authorization', transfer.signed_ticket)
-proxy_connection.putheader('Content-Range',
-                           "bytes %d-%d/%d" % (0, image_size - 1, image_size))
 proxy_connection.putheader('Content-Length', "%d" % (image_size,))
 proxy_connection.endheaders()
 
